<?php
/**
 * Camaraderie ( functions.php )
 *
 * @package     Camaraderie
 * @copyright   Copyright (C) 2017-2019. Benjamin Lu
 * @license     GNU General Public License v2 or later ( https://www.gnu.org/licenses/gpl-2.0.html )
 * @author      Benjamin Lu ( https://benjlu.com )
 */

/**
 * Table of Content
 *
 * 1.0 - Compatibility Check
 * 2.0 - Autoload Backrop Core
 * 3.0 - Additional Features
 */

/**
 * 1.0 - Compatibility Check
 */
function camaraderie_compatibility_check() {
	if ( version_compare( $GLOBALS['wp_version'], '5.0', '<' ) ) {
		return sprintf(
			// translators: 1 =  a version string, 2 = current wp version string.
			__( 'Camaraderie requires at least WordPress version %1$s. You are currently running %2$s. Please upgrade and try again.', 'camaraderie' ),
			'5.0',
			$GLOBALS['wp_version']
		);
	} elseif ( version_compare( PHP_VERSION, '5.6', '<' ) ) {
		return sprintf(
			// translators: 1 =  a version string, 2 = current wp version string.
			__( 'Camaraderie requires at least PHP version %1$s. You are currently running %2$s. Please upgrade and try again.', 'camaraderie' ),
			'5.6',
			PHP_VERSION
		);
	}
	return '';
}

/**
 * Triggered after switch themes and check if it meets the requirements.
 */
function camaraderie_switch_theme() {
	if ( version_compare( $GLOBALS['wp_version'], '5.0', '<' ) || version_compare( PHP_VERSION, '5.6', '<' ) ) {
		switch_theme( get_option( 'theme_switched' ) );
		add_action( 'admin_notices', 'camaraderie_upgrade_notice' );
	}
	return false;
}
add_action( 'after_switch_theme', 'camaraderie_switch_theme' );

/**
 * Displays an error if it doesn't meet the requirements.
 */
function camaraderie_upgrade_notice() {
	printf( '<div class="error"><p>%s</p></div>', esc_html( camaraderie_compatibility_check() ) );
}

/**
 * 2.0 - Autoload Backrop Core
 */
if ( file_exists( get_parent_theme_file_path( '/vendor/autoload.php' ) ) ) {
	require_once get_parent_theme_file_path( '/vendor/autoload.php' );
}

/**
 * 3.0 - Additional Features
 */
array_map(
	function( $inline_styles ) {
		require_once get_parent_theme_file_path( "/includes/inline-styles/{$inline_styles}.php" );
	},
	[
		'custom-image',
		'header-image',
	]
);

array_map(
	function( $customize ) {
		require_once get_parent_theme_file_path( "/includes/customize/{$customize}.php" );
	},
	[
		'landing-page',
		'theme-options',
		'title-description',
		'validations',
	]
);

array_map(
	function( $config ) {
		require_once get_parent_theme_file_path( "/includes/config/{$config}.php" );
	},
	[
		'functions-portfolio',
	]
);

array_map(
	function( $sidebar ) {
		require_once get_parent_theme_file_path( "/includes/sidebar/{$sidebar}.php" );
	},
	[
		'sidebar-portfolio',
	]
);

