<?php
/**
 * Camaraderie ( landing-page.php )
 *
 * @package     Camaraderie
 * @copyright   Copyright (C) 2017-2019. Benjamin Lu
 * @license     GNU General Public License v2 or later ( https://www.gnu.org/licenses/gpl-2.0.html )
 * @author      Benjamin Lu ( https://benjlu.com )
 */

/**
 * Define namespace
 */
namespace Camaraderie;

/**
 * Table of Content
 *
 * 1.0 - Customize ( Landing Page )
 */

/**
 * 1.0 - Customize ( Landing Page )
 *
 * @param array $wp_customize landing page.
 */
function load_landing_page( $wp_customize ) {
	/**
	 * Enable Home Section
	 */
	$wp_customize->add_panel(
		'home_section',
		array(
			'title'    => esc_html__( 'Home Section', 'camaraderie' ),
			'priority' => 10,
		)
	);

	/**
	 * Enables Jetpack Portfolio
	 */
	if ( class_exists( 'Jetpack_Portfolio' ) ) {
		$wp_customize->add_section(
			'portfolio_section',
			array(
				'title'    => esc_html__( 'Portfolio Section', 'camaraderie' ),
				'panel'    => 'home_section',
				'priority' => 5,
			)
		);
		$wp_customize->add_setting(
			'jetpack_portfolio_display',
			array(
				'sanitize_callback' => 'Camaraderie\sanitize_checkbox',
			)
		);

		$wp_customize->add_control(
			'jetpack_portfolio_display',
			array(
				'label'    => esc_html__( 'Enable Portfolio Section', 'camaraderie' ),
				'type'     => 'checkbox',
				'section'  => 'portfolio_section',
				'settings' => 'jetpack_portfolio_display',
				'priority' => 5,
			)
		);

		$wp_customize->add_setting(
			'jetpack_portfolio_background',
			array(
				'default'           => '#ffffff',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new \WP_Customize_Color_Control(
				$wp_customize,
				'jetpack_portfolio_background',
				array(
					'label'    => esc_html__( 'Background Color', 'camaraderie' ),
					'section'  => 'portfolio_section',
					'settings' => 'jetpack_portfolio_background',
					'priority' => 10,
				)
			)
		);

		$wp_customize->add_setting(
			'portfolio_title',
			array(
				'default'           => esc_html__( 'Projects', 'camaraderie' ),
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'portfolio_title',
			array(
				'label'    => esc_html__( 'Portfolio Title', 'camaraderie' ),
				'type'     => 'text',
				'section'  => 'portfolio_section',
				'settings' => 'portfolio_title',
				'priority' => 10,
			)
		);

		$wp_customize->add_setting(
			'portfolio_description',
			array(
				'default'           => esc_html__( 'Some of my recent Works.', 'camaraderie' ),
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'portfolio_description',
			array(
				'label'    => esc_html__( 'Portfolio Archive Description', 'camaraderie' ),
				'type'     => 'text',
				'section'  => 'portfolio_section',
				'settings' => 'portfolio_description',
				'priority' => 10,
			)
		);

		$wp_customize->add_setting(
			'related_display',
			array(
				'sanitize_callback' => 'Camaraderie\sanitize_checkbox',
			)
		);

		$wp_customize->add_control(
			'related_display',
			array(
				'label'       => esc_html__( 'Enable Related Items', 'camaraderie' ),
				'description' => esc_html__( 'Related Items when enabled, will appear at the bottom page when using Jetpack Portfolio.', 'camaraderie' ),
				'type'        => 'checkbox',
				'section'     => 'portfolio_section',
				'settings'    => 'related_display',
				'priority'    => 30,
			)
		);

		$wp_customize->add_setting(
			'related_title',
			array(
				'default'           => esc_html__( 'Related Items', 'camaraderie' ),
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'related_title',
			array(
				'label'    => esc_html__( 'Related Title', 'camaraderie' ),
				'type'     => 'text',
				'section'  => 'portfolio_section',
				'settings' => 'related_title',
				'priority' => 35,
			)
		);
	}

	/**
	 * Enables Blog Section
	 */
	$wp_customize->add_section(
		'blog_section',
		array(
			'title'       => esc_html__( 'Blog Section', 'camaraderie' ),
			'description' => esc_html__( 'The Blog Section when enabled as a section in the landing page allowing you to customize features below.', 'camaraderie' ),
			'panel'       => 'home_section',
			'priority'    => 5,
		)
	);

	$wp_customize->add_setting(
		'blog_display',
		array(
			'sanitize_callback' => 'Camaraderie\sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'blog_display',
		array(
			'label'    => esc_html__( 'Enable Blog Section', 'camaraderie' ),
			'type'     => 'checkbox',
			'section'  => 'blog_section',
			'settings' => 'blog_display',
			'priority' => 5,
		)
	);

	$wp_customize->add_setting(
		'blog_background',
		array(
			'default'           => 'eeeeee',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new \WP_Customize_Color_Control(
			$wp_customize,
			'blog_background',
			array(
				'label'    => esc_html__( 'Background Color', 'camaraderie' ),
				'section'  => 'blog_section',
				'settings' => 'blog_background',
				'priority' => 10,
			)
		)
	);

	$wp_customize->add_setting(
		'blog_title',
		array(
			'default'           => esc_html__( 'Blog', 'camaraderie' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'blog_title',
		array(
			'label'    => esc_html__( 'Blog Title', 'camaraderie' ),
			'type'     => 'text',
			'section'  => 'blog_section',
			'settings' => 'blog_title',
			'priority' => 10,
		)
	);

	$wp_customize->add_setting(
		'blog_description',
		array(
			'default'           => esc_html__( 'Latest News', 'camaraderie' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'blog_description',
		array(
			'label'    => esc_html__( 'Blog Description', 'camaraderie' ),
			'type'     => 'text',
			'section'  => 'blog_section',
			'settings' => 'blog_description',
			'priority' => 10,
		)
	);

	/**
	 * Enable Testimonial Section
	 */
	if ( class_exists( 'Jetpack_Testimonial' ) ) {
		$wp_customize->add_section(
			'testimonial_section',
			array(
				'title' => esc_html__( 'Testimonial Section', 'camaraderie' ),
				'panel' => 'home_section',
			)
		);
		$wp_customize->add_setting(
			'testimonial_display',
			array(
				'sanitize_callback' => 'Camaraderie\sanitize_checkbox',
			)
		);

		$wp_customize->add_control(
			'testimonial_display',
			array(
				'label'    => esc_html__( 'Enable Testimonial Section', 'camaraderie' ),
				'type'     => 'checkbox',
				'section'  => 'testimonial_section',
				'settings' => 'testimonial_display',
				'priority' => 5,
			)
		);

		$wp_customize->add_setting(
			'testimonial_background',
			array(
				'default'           => 'ffffff',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new \WP_Customize_Color_Control(
				$wp_customize,
				'testimonial_background',
				array(
					'label'    => esc_html__( 'Background Color', 'camaraderie' ),
					'section'  => 'testimonial_section',
					'settings' => 'testimonial_background',
					'priority' => 10,
				)
			)
		);

		$wp_customize->add_setting(
			'testimonial_title',
			array(
				'default'           => esc_html__( 'Testimonials', 'camaraderie' ),
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'testimonial_title',
			array(
				'label'    => esc_html__( 'Testimonial Archive Title', 'camaraderie' ),
				'type'     => 'text',
				'section'  => 'testimonial_section',
				'settings' => 'testimonial_title',
				'priority' => 10,
			)
		);

		$wp_customize->add_setting(
			'testimonial_description',
			array(
				'default'           => esc_html__( 'What People Say About Us.', 'camaraderie' ),
				'sanitize_callback' => 'sanitize_text_field',
			)
		);

		$wp_customize->add_control(
			'testimonial_description',
			array(
				'label'    => esc_html__( 'Testimonial Archive Description', 'camaraderie' ),
				'type'     => 'text',
				'section'  => 'testimonial_section',
				'settings' => 'testimonial_description',
				'priority' => 10,
			)
		);
	}

	// Contact Information Section.
	$wp_customize->add_section(
		'contact_section',
		array(
			'title' => esc_html__( 'Contact Section', 'camaraderie' ),
			'panel' => 'home_section',
		)
	);

	$wp_customize->add_setting(
		'contact_display',
		array(
			'sanitize_callback' => 'Camaraderie\sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'contact_display',
		array(
			'label'       => esc_html__( 'Enable Contact Section', 'camaraderie' ),
			'description' => esc_html__( 'This section is intended to be used only for contact form and will need to activate Contact Form 7 plugin for this to work.', 'camaraderie' ),
			'type'        => 'checkbox',
			'section'     => 'contact_section',
			'settings'    => 'contact_display',
			'priority'    => 5,
		)
	);

	$wp_customize->add_setting(
		'contact_background',
		array(
			'default'           => '#000000',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new \WP_Customize_Color_Control(
			$wp_customize,
			'contact_background',
			array(
				'label'    => esc_html__( 'Background Color', 'camaraderie' ),
				'section'  => 'contact_section',
				'settings' => 'contact_background',
				'priority' => 10,
			)
		)
	);

	$wp_customize->add_setting(
		'contact_description',
		array(
			'default'           => esc_html__( 'Questions or Hire Me.', 'camaraderie' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'contact_description',
		array(
			'label'    => esc_html__( 'Contact Description', 'camaraderie' ),
			'type'     => 'text',
			'section'  => 'contact_section',
			'settings' => 'contact_description',
			'priority' => 15,
		)
	);

	$wp_customize->add_setting(
		'contact_dropdown',
		array(
			'sanitize_callback' => 'Camaraderie\sanitize_dropdown',
		)
	);

	$wp_customize->add_control(
		'contact_dropdown',
		array(
			'type'    => 'dropdown-pages',
			'section' => 'contact_section',
			'label'   => esc_html__( 'Custom Dropdown Pages', 'camaraderie' ),
		)
	);
}
add_action( 'customize_register', __NAMESPACE__ . '\load_landing_page', 11 );

/**
 * Loading Landing Page Styles.
 */
function load_landing_page_styles() {
	$portfolio_background   = get_theme_mod( 'jetpack_portfolio_background', '#ffffff' );
	$blog_background        = get_theme_mod( 'blog_background', '#eeeeee' );
	$testimonial_background = get_theme_mod( 'testimonial_background', '#ffffff' );
	$contact_background     = get_theme_mod( 'contact_background', '#000000' ); ?>

	<style type="text/css">
		.section-portfolio {
			background: <?php echo esc_html( $portfolio_background ); ?>;
		}

		.section-blog {
			background: <?php echo esc_html( $blog_background ); ?>;
		}

		.section-testimonial {
			background: <?php echo esc_html( $testimonial_background ); ?>;
		}

		.section-contact {
			background: <?php echo esc_html( $contact_background ); ?>;
		}
	</style>
	<?php
}
add_action( 'wp_head', __NAMESPACE__ . '\load_landing_page_styles' );
